@@ -4,7 +4,7 @@ test_that("add tests", {
   filename <- "example.Rmd"
   unlink(filename)
   expect_false(filename %in% dir())
-  build_example()
+  build_example(open = FALSE)
   expect_true(filename %in% dir())
   expect_true(any(grepl("Example Document", readLines(filename))))
   unlink(filename)
